@@ -2,6 +2,7 @@ import dataclasses
 import hashlib
 import logging
 from typing import Optional
+from azure.identity import DefaultAzureCredential
 from azure.storage.blob import BlobClient, ContainerClient
 import irisml.core
 
@@ -43,10 +44,10 @@ class Task(irisml.core.TaskBase):
             raise ValueError("You must specify blob_path if container_url is used.")
 
         if self.config.blob_url:
-            blob_client = BlobClient.from_blob_url(self.config.blob_url)  # TODO: Authentication?
+            blob_client = BlobClient.from_blob_url(self.config.blob_url, credential=DefaultAzureCredential())
             downloaded_bytes = blob_client.download_blob().readall()
         elif self.config.container_url:
-            container_client = ContainerClient.from_container_url(self.config.container_url)
+            container_client = ContainerClient.from_container_url(self.config.container_url, credential=DefaultAzureCredential())
             downloaded_bytes = container_client.download_blob(self.config.blob_path).readall()
 
         file_hash = hashlib.sha1(downloaded_bytes).hexdigest()
